# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_drt_tools_global_optspecs
	string join \n force-download f/force n v/verbose q/quiet mirror= buildd= h/help
end

function __fish_drt_tools_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_drt_tools_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_drt_tools_using_subcommand
	set -l cmd (__fish_drt_tools_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c drt-tools -n "__fish_drt_tools_needs_command" -l mirror -d 'Archive mirror' -r
complete -c drt-tools -n "__fish_drt_tools_needs_command" -l buildd -d 'buildd server' -r
complete -c drt-tools -n "__fish_drt_tools_needs_command" -l force-download -d 'Force download of files'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -s f -l force -d 'Force processing'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -s n -d 'Only print actions to perform without running any commands'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -s h -l help -d 'Print help'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "process-excuses" -d 'Process current excuses.yaml and prepare a list of binNMUs required for testing migration and list of unblocks'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "nmu-transition" -d 'Prepare and schedule binNMUs for a transition'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "nmu-buildinfo" -d 'Prepare binNMUs based on a list of buildinfo files'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "grep-excuses" -d 'Grep excuses for a list of packages and/or maintainers'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "nmu-eso" -d 'Prepare binNMUs to rebuild for outdated Built-Using'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "nmu-version-skew" -d 'Prepare rebuilds for version skew in Multi-Arch: same packages'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "nmu-list" -d 'BinNMU a list of packages'
complete -c drt-tools -n "__fish_drt_tools_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand process-excuses" -l ignore-age -d 'Ignore age to identify packages to rebuild'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand process-excuses" -l ignore-autopkgtests -d 'Ignore results from autopkgtests'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand process-excuses" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand process-excuses" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand process-excuses" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -s m -l message -d 'Message for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -l bp -d 'Build priority. If specified, the binNMUs are scheduled with the given build priority. Builds with a positive priority will be built earlier' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -l dw -d 'Dependency-wait. If specified, the builds will wait until the given dependency relation is satisfied' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -l extra-depends -d 'Extra dependencies. If specified, the given dependency will be installed during the build' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -s s -l suite -d 'Suite for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -s a -l architecture -d 'Set architectures for binNMUs. If no architectures are specified, the binNMUs are scheduled with ANY' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-transition" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -s m -l message -d 'Message for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -l bp -d 'Build priority. If specified, the binNMUs are scheduled with the given build priority. Builds with a positive priority will be built earlier' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -l dw -d 'Dependency-wait. If specified, the builds will wait until the given dependency relation is satisfied' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -l extra-depends -d 'Extra dependencies. If specified, the given dependency will be installed during the build' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -s s -l suite -d 'Suite for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -s a -l architecture -d 'Set architectures for binNMUs. If no architectures are specified, the binNMUs are scheduled with ANY' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-buildinfo" -s h -l help -d 'Print help'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand grep-excuses" -l autopkgtests -d 'Currently not implemented'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand grep-excuses" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand grep-excuses" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand grep-excuses" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-eso" -l bp -d 'Build priority. If specified, the binNMUs are scheduled with the given build priority. Builds with a positive priority will be built earlier' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-eso" -s s -l suite -d 'Suite for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-eso" -l field -d 'Select the binary package field to check for outdated information. By default, the `Built-Using` field is checked' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-eso" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-eso" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-eso" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-version-skew" -l bp -d 'Build priority. If specified, the binNMUs are scheduled with the given build priority. Builds with a positive priority will be built earlier' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-version-skew" -s s -l suite -d 'Suite for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-version-skew" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-version-skew" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-version-skew" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -s m -l message -d 'Message for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -l bp -d 'Build priority. If specified, the binNMUs are scheduled with the given build priority. Builds with a positive priority will be built earlier' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -l dw -d 'Dependency-wait. If specified, the builds will wait until the given dependency relation is satisfied' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -l extra-depends -d 'Extra dependencies. If specified, the given dependency will be installed during the build' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -s s -l suite -d 'Suite for binNMUs' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -s a -l architecture -d 'Set architectures for binNMUs. If no architectures are specified, the binNMUs are scheduled with ANY' -r
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -s v -l verbose -d 'Increase logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -s q -l quiet -d 'Decrease logging verbosity'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand nmu-list" -s h -l help -d 'Print help (see more with \'--help\')'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "process-excuses" -d 'Process current excuses.yaml and prepare a list of binNMUs required for testing migration and list of unblocks'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "nmu-transition" -d 'Prepare and schedule binNMUs for a transition'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "nmu-buildinfo" -d 'Prepare binNMUs based on a list of buildinfo files'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "grep-excuses" -d 'Grep excuses for a list of packages and/or maintainers'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "nmu-eso" -d 'Prepare binNMUs to rebuild for outdated Built-Using'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "nmu-version-skew" -d 'Prepare rebuilds for version skew in Multi-Arch: same packages'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "nmu-list" -d 'BinNMU a list of packages'
complete -c drt-tools -n "__fish_drt_tools_using_subcommand help; and not __fish_seen_subcommand_from process-excuses nmu-transition nmu-buildinfo grep-excuses nmu-eso nmu-version-skew nmu-list help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
